#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 butcher
version:              1.3.3.2
visibility:           public
id:                   butcher-1.3.3.2-7PxlZAPrQLl52Z1DNeMWJI
key:                  butcher-1.3.3.2-7PxlZAPrQLl52Z1DNeMWJI
license:              BSD-3-Clause
copyright:            Copyright (C) 2016-2020 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
stability:            experimental
homepage:             https://github.com/lspitzner/butcher/
synopsis:
    Chops a command or program invocation into digestable pieces.

description:
    See the <https://github.com/lspitzner/butcher/blob/master/README.md README> (it is properly formatted on github).

category:             UI
abi:                  4b132aa224de007a4f7c1e920201936d
exposed:              True
exposed-modules:
    UI.Butcher.Monadic UI.Butcher.Monadic.BuiltinCommands
    UI.Butcher.Monadic.Command UI.Butcher.Monadic.Flag
    UI.Butcher.Monadic.IO UI.Butcher.Monadic.Interactive
    UI.Butcher.Monadic.Param UI.Butcher.Monadic.Pretty
    UI.Butcher.Monadic.Types

hidden-modules:
    UI.Butcher.Monadic.Internal.Types UI.Butcher.Monadic.Internal.Core

import-dirs:          /usr/lib/ghc-9.6.6/site-local/butcher-1.3.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/butcher-1.3.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/butcher-1.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-butcher
hs-libraries:         HSbutcher-1.3.3.2-7PxlZAPrQLl52Z1DNeMWJI
depends:
    base-4.18.2.1 bifunctors-5.6.3-7bjHyYyfYBQARUyvp7mikv
    containers-0.6.7 deque-0.4.4.2-93ZMnAiFPVKIBIuT57MAeC
    extra-1.7.16-aWEq6cZZ289lIc6yxljo5 free-5.2-3bhu4Xl1KTk3zcTl87Wikp
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-1JCZcjTuCbDB2Q9keDntvT mtl-2.3.1
    multistate-0.8.0.4-Cr6hv7mR8GEowia6x8C4y pretty-1.1.3.6
    transformers-0.6.1.0 unsafe-0.0-BBDazQPXbQ7ErhLr2KtCI4
    void-0.7.4-Ab78HEYVlxC2PerDGXO6Wd

haddock-interfaces:   /usr/share/doc/haskell-butcher/html/butcher.haddock
haddock-html:         /usr/share/doc/haskell-butcher/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

